==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/enums/PrivateEndpointConnectionProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * State of Private Endpoint Connection.
 */
public enum class PrivateEndpointConnectionProvisioningState(
    public val javaValue:
    com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState,
) :
    ConvertibleToJava<com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState> {
    Unknown(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Unknown),
    Succeeded(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Succeeded),
    Creating(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Creating),
    Updating(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Updating),
    UpdatingByProxy(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.UpdatingByProxy),
    Deleting(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Deleting),
    DeletingByProxy(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.DeletingByProxy),
    Deleted(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Deleted),
    ;

    override fun toJava():
        com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState):
            PrivateEndpointConnectionProvisioningState =
            PrivateEndpointConnectionProvisioningState.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/enums/PrivateEndpointConnectionProvisioningState.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * State of Private Endpoint Connection.
 */
public enum class PrivateEndpointConnectionProvisioningState(
    public val javaValue: com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState,
) :
    ConvertibleToJava<com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState> {
    Unknown(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Unknown),
    Succeeded(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Succeeded),
    Creating(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Creating),
    Updating(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Updating),
    UpdatingByProxy(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.UpdatingByProxy),
    Deleting(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Deleting),
    DeletingByProxy(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.DeletingByProxy),
    Deleted(com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState.Deleted),
    ;

    override fun toJava(): com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.notificationhubs.enums.PrivateEndpointConnectionProvisioningState): PrivateEndpointConnectionProvisioningState =
            PrivateEndpointConnectionProvisioningState.values().first { it.javaValue == javaType }
    }
}
